==> oauth-login-service-1.11.4-sources.jar: org/clazzes/login/oauth/OAuthAbstrServlet.java <==
package org.clazzes.login.oauth;

import java.util.Locale;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.xml.stream.XMLOutputFactory;

import org.clazzes.util.http.LocaleHelper;

public abstract class OAuthAbstrServlet extends HttpServlet {

    private static final long serialVersionUID = 3065823382387713495L;

    protected static final String XHTML_NS_URI = "http://www.w3.org/1999/xhtml";
    protected static final XMLOutputFactory xmlOutputFactory;

    protected AuthStateCache authStateCache;
    protected ConfigurationService configurationService;
    protected OAuthHttpClient oauthHttpClient;
    protected OAuthHttpLoginService oauthHttpLoginService;

    static {
        xmlOutputFactory = XMLOutputFactory.newFactory();
        xmlOutputFactory.setProperty(XMLOutputFactory.IS_REPAIRING_NAMESPACES,true);
    }
    

    protected static Locale getRequestLocale(HttpServletRequest req) {
        
        Locale locale = req.getLocale();
        
        String locale_s = req.getParameter("locale");
        
        if (locale_s != null) {
            locale = LocaleHelper.localeFromXsLanguage(locale_s);
        }
        
        return locale;
    }

    public OAuthAbstrServlet() {
        super();
    }

    public void setAuthStateCache(AuthStateCache authStateCache) {
        this.authStateCache = authStateCache;
    }

    public void setConfigurationService(ConfigurationService configurationService) {
        this.configurationService = configurationService;
    }

    public void setOauthHttpClient(OAuthHttpClient oauthHttpClient) {
        this.oauthHttpClient = oauthHttpClient;
    }

    public void setOauthHttpLoginService(OAuthHttpLoginService oauthHttpLoginService) {
        this.oauthHttpLoginService = oauthHttpLoginService;
    }

}

==> oauth-login-service-2.0.3-sources.jar: org/clazzes/login/oauth/OAuthAbstrServlet.java <==
package org.clazzes.login.oauth;

import java.util.Locale;

import jakarta.servlet.http.HttpServlet;
import jakarta.servlet.http.HttpServletRequest;
import javax.xml.stream.XMLOutputFactory;

import org.clazzes.util.http.LocaleHelper;

public abstract class OAuthAbstrServlet extends HttpServlet {

    private static final long serialVersionUID = 3065823382387713495L;

    protected static final String XHTML_NS_URI = "http://www.w3.org/1999/xhtml";
    protected static final XMLOutputFactory xmlOutputFactory;

    protected AuthStateCache authStateCache;
    protected ConfigurationService configurationService;
    protected OAuthHttpClient oauthHttpClient;
    protected OAuthHttpLoginService oauthHttpLoginService;

    static {
        xmlOutputFactory = XMLOutputFactory.newFactory();
        xmlOutputFactory.setProperty(XMLOutputFactory.IS_REPAIRING_NAMESPACES,true);
    }


    protected static Locale getRequestLocale(HttpServletRequest req) {

        Locale locale = req.getLocale();

        String locale_s = req.getParameter("locale");

        if (locale_s != null) {
            locale = LocaleHelper.localeFromXsLanguage(locale_s);
        }

        return locale;
    }

    public OAuthAbstrServlet() {
        super();
    }

    public void setAuthStateCache(AuthStateCache authStateCache) {
        this.authStateCache = authStateCache;
    }

    public void setConfigurationService(ConfigurationService configurationService) {
        this.configurationService = configurationService;
    }

    public void setOauthHttpClient(OAuthHttpClient oauthHttpClient) {
        this.oauthHttpClient = oauthHttpClient;
    }

    public void setOauthHttpLoginService(OAuthHttpLoginService oauthHttpLoginService) {
        this.oauthHttpLoginService = oauthHttpLoginService;
    }

}
